@@ -910,67 +910,72 @@ def scheduled_compile_measure_task(self, force=False):
         "Launching scheduled compile measure task for synchronized datas"
     )
     yesterday = datetime.date.today() - datetime.timedelta(1)
-    upload = AccountingOperationUpload.query().filter(
+    uploads = AccountingOperationUpload.query().filter(
         AccountingOperationUpload.filetype ==
         AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING
     ).filter(
         AccountingOperationUpload.updated_at >= yesterday
     ).order_by(
         desc(AccountingOperationUpload.id)
-    ).first()
-    if upload is None:
+    ).all()
+    if not uploads:
         logger.info(
             "ABORT : no upload with 'synchronized_accounting' type \
 since yesterday"
         )
     else:
-        transaction.begin()
-        logger.info(
-            "Compiling the measures for upload {} ...".format(upload.id)
-        )
-        upload_object = AccountingOperationUpload.get(upload.id)
-        measure_compiler_factories = [
-            TreasuryMeasureCompiler,
-            IncomeStatementMeasureCompiler,
-        ]
-        for measure_compiler_factory in measure_compiler_factories:
-            operations = None
-            if measure_compiler_factory == TreasuryMeasureCompiler:
-                operations = _collect_operations(
-                    upload.id,
-                    upload_object.filetype,
-                    upload_object.created_at.date()
-                )
-            else:
-                operations = AccountingOperation.query().filter_by(
-                    upload_id=upload.id
-                ).all()
-            try:
-                measure_compiler = measure_compiler_factory(
-                    upload_object, operations
-                )
-                measure_compiler.process_datas()
-            except Exception as err:
-                transaction.abort()
-                logger.exception("ERROR : {}".format(err.message))
-                mail_addresses = get_recipients_addresses(self.request)
-                if mail_addresses:
-                    send_error(
-                        self.request,
-                        mail_addresses,
-                        measure_compiler.label,
-                        err.message
+        for upload in uploads:
+            transaction.begin()
+            logger.info(
+                "Compiling the measures for upload {} ...".format(upload.id)
+            )
+            upload_object = AccountingOperationUpload.get(upload.id)
+            measure_compiler_factories = [
+                TreasuryMeasureCompiler,
+                IncomeStatementMeasureCompiler,
+            ]
+            for measure_compiler_factory in measure_compiler_factories:
+                operations = None
+                if measure_compiler_factory == TreasuryMeasureCompiler:
+                    operations = _collect_operations(
+                        upload.id,
+                        upload_object.filetype,
+                        upload_object.created_at.date()
                     )
-                    logger.error(
-                        "An error mail has been sent to {0}".format(
-                            mail_addresses
+                else:
+                    operations = AccountingOperation.query().filter_by(
+                        upload_id=upload.id
+                    ).all()
+                try:
+                    measure_compiler = measure_compiler_factory(
+                        upload_object, operations
+                    )
+                    measure_compiler.process_datas()
+                except Exception as err:
+                    transaction.abort()
+                    logger.exception("ERROR : {}".format(err))
+                    mail_addresses = get_recipients_addresses(self.request)
+                    if mail_addresses:
+                        send_error(
+                            self.request,
+                            mail_addresses,
+                            measure_compiler.label,
+                            err
                         )
+                        logger.error(
+                            "An error mail has been sent to {}".format(
+                                mail_addresses
+                            )
+                        )
+                    logger.exception(
+                        "Transaction has been rollbacked"
                     )
-                logger.exception(
-                    "Transaction has been rollbacked"
-                )
-                return False
-        transaction.commit()
+                    return False
+            transaction.commit()
+            logger.info(
+                "SUCCESS : Measure computing transaction has been commited \
+                    for upload {}".format(upload.id)
+            )
         logger.info(
-            "SUCCESS : Measure computing transaction has been commited"
+            "End of scheduled compile measure task for synchronized datas"
         )
