@@ -1,7 +1,6 @@
 import transaction
 from pyramid_celery import celery_app
 from endi.export.task_pdf import ensure_task_pdf_persisted
-from endi.models.task import Task
 from endi_celery.hacks import (
     setup_rendering_hacks,
 )
@@ -12,13 +11,13 @@ from endi_celery.mail import (
     send_supplier_new_invoice_mail,
 )
 from endi_celery.tasks import utils
-
+from endi_celery.transactional_task import task_tm
 
 logger = utils.get_logger(__name__)
 
 
-@celery_app.task(bind=True)
-def scheduled_render_pdf_task(self, document_id):
+@task_tm
+def scheduled_render_pdf_task(document_id):
     logger.debug("Scheduling a PDF render Task for {}".format(document_id))
     document = utils.get_task(document_id)
     if document is None:
@@ -35,8 +34,8 @@ def scheduled_render_pdf_task(self, document_id):
         transaction.abort()
 
 
-@celery_app.task(bind=True)
-def async_internalestimation_valid_callback(self, document_id):
+@task_tm
+def async_internalestimation_valid_callback(document_id):
     """
     Handle the transfer of an InternalEstimation to the Client Company
 
@@ -57,10 +56,14 @@ def async_internalestimation_valid_callback(self, document_id):
             )
         )
         return
+    else:
+        logger.debug("Found the document {}".format(document))
+        logger.debug(id(document))
 
     request = celery_app.conf['PYRAMID_REQUEST']
     # Ensure layout_manager
     try:
+        logger.debug("Setup rendering hacks")
         setup_rendering_hacks(request, document)
         order = document.sync_with_customer(request)
         send_customer_new_order_mail(request, order)
@@ -71,8 +74,8 @@ def async_internalestimation_valid_callback(self, document_id):
         transaction.abort()
 
 
-@celery_app.task(bind=True)
-def async_internalinvoice_valid_callback(self, document_id):
+@task_tm
+def async_internalinvoice_valid_callback(document_id):
     """
     Handle the transfer of an InternalInvoice to the Client Company
 
